
package WWW::Virull;

use strict;
use warnings 'all';
our $VERSION = '0.001';

1;# return true:

=pod

=head1 NAME

WWW::Virull - Remote api to Virull.com

=head1 SYNOPSIS

  use WWW::Virull;
  
  # TBD

=head1 DESCRIPTION

Virull.com offers file sharing services.

C<WWW::Virull> provides (or I<will> provide) a programming interface to the Virull.com API.

=head1 SEE ALSO

L<http://www.virull.com/>

=head1 AUTHOR

John Drago <jdrago_999@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright 2009 John Drago.

This software is Free software and may be used and redistributed under the
same terms as Perl itself.

=cut

